@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.6/src/DwmIpv4Prefix.cc 11108 $
-// @(#) $Id: DwmIpv4Prefix.cc 11108 2020-09-07 22:44:06Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.7/src/DwmIpv4Prefix.cc 11410 $
+// @(#) $Id: DwmIpv4Prefix.cc 11410 2020-12-11 08:20:53Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007
 //  All rights reserved.
@@ -52,6 +52,7 @@ extern "C" {
 #include <cassert>
 #include <cstdio>
 #include <cstdlib>
+#include <regex>
 #include <sstream>
 #include <string>
 
@@ -59,7 +60,7 @@ extern "C" {
 #include "DwmStringUtils.hh"
 #include "DwmSvnTag.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.6/src/DwmIpv4Prefix.cc 11108 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.7/src/DwmIpv4Prefix.cc 11410 $");
 
 using namespace std;
 
@@ -70,11 +71,11 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   Ipv4Prefix::Ipv4Prefix()
   {
-    this->_data[0] = 0x00;
-    this->_data[1] = 0x00;
-    this->_data[2] = 0x00;
-    this->_data[3] = 0x00;
-    this->_data[4] = 0;
+    this->_data[0] = 0xFF;
+    this->_data[1] = 0xFF;
+    this->_data[2] = 0xFF;
+    this->_data[3] = 0xFF;
+    this->_data[4] = 32;
   }
   
   //--------------------------------------------------------------------------
@@ -82,7 +83,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   Ipv4Prefix::Ipv4Prefix(const Ipv4Address & network, uint8_t maskLength)
   {
-    this->Set(network,maskLength);
+    this->Set(network, maskLength);
   }
 
   //--------------------------------------------------------------------------
@@ -99,33 +100,35 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   Ipv4Prefix::Ipv4Prefix(const string & prefix)
   {
-    vector<string>  stringVec;
-    if (StringUtils::StringToVector(prefix, '/', stringVec)) {
-      if (stringVec.size() == 1) {
-        string  ipAddr = stringVec[0];
-        vector<string>  octetVec;
-        StringUtils::StringToVector(ipAddr, '.', octetVec);
-        uint8_t maskLen = octetVec.size() * 8;
-        for (size_t i = octetVec.size(); i < 4; ++i) {
-          ipAddr += ".0";
-        }
-        this->Set(ipAddr, maskLen);
+    static const regex
+    rgx("([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])"
+        "([.]([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]))?"
+        "([.]([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]))?"
+        "([.]([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5]))?"
+        "(\\/([0-9]|[12][0-9]|[3][012]))?",
+        std::regex::ECMAScript | std::regex::optimize);
+    smatch  sm;
+    if (regex_match(prefix, sm, rgx) && (sm.size() == 10)) {
+      memset(_data, 0, sizeof(_data));
+      uint8_t  *p = _data;
+      for (int i = 1; i < 9 && (sm[i].length() > 0); i += 2) {
+        *p++ = stoul(sm[i].str());
+        _data[4] += 8;
       }
-      else if (stringVec.size() == 2) {
-        string  ipAddr = stringVec[0];
-        vector<string>  octetVec;
-        StringUtils::StringToVector(ipAddr, '.', octetVec);
-        for (size_t i = octetVec.size(); i < 4; ++i) {
-          ipAddr += ".0";
+      if (! sm[9].str().empty()) {
+        _data[4] = stoul(sm[9].str());
+        if (_data[4] == 0) {
+          memset(_data, 0, sizeof(_data[0]) * 4);
+        }
+        else if (_data[4] < 32) {
+          uint32_t  mask = htonl(0xffffffff << (32 - _data[4]));
+          *(uint32_t *)_data &= mask;
         }
-        this->Set(ipAddr, atoi(stringVec[1].c_str()));
-      }
-      else {
-        this->Set(string("255.255.255.255"), 32);
       }
     }
     else {
-      this->Set(string("255.255.255.255"), 32);
+      memset(_data, 0xFF, sizeof(_data[0]) * 4);
+      _data[4] = 32;
     }
   }
 
