@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.6/src/DwmIpv6Prefix.cc 11306 $
-// @(#) $Id: DwmIpv6Prefix.cc 11306 2020-11-25 21:31:44Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.7/src/DwmIpv6Prefix.cc 11407 $
+// @(#) $Id: DwmIpv6Prefix.cc 11407 2020-12-10 22:21:25Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007, 2020
 //  All rights reserved.
@@ -53,7 +53,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmIpv6Prefix.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.6/src/DwmIpv6Prefix.cc 11306 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.8.7/src/DwmIpv6Prefix.cc 11407 $");
 
 namespace Dwm {
 
@@ -234,6 +234,24 @@ namespace Dwm {
     return(rc);
   }
 
+  //--------------------------------------------------------------------------
+  //!  
+  //--------------------------------------------------------------------------
+  bool Ipv6Prefix::operator != (const Ipv6Prefix & prefix) const
+  {
+    bool  rc = false;
+    if (_length != prefix._length) {
+      rc = true;
+    }
+    else {
+      if (memcmp(_addr.s6_addr, prefix._addr.s6_addr,
+                 sizeof(_addr.s6_addr)) != 0) {
+        rc = true;
+      }
+    }
+    return rc;
+  }
+  
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
